// SPDX-License-Identifier: AGPL-3.0-or-later
// SPDX-FileCopyrightText: 2023-2024 swt23w23
package catering.inventory;

import static org.salespointframework.core.Currencies.EURO;

import org.javamoney.moneta.Money;
import org.salespointframework.catalog.Product;
import org.salespointframework.inventory.UniqueInventoryItem;

import catering.catalog.Rentable;
import jakarta.validation.constraints.NotNull;
import jakarta.validation.constraints.PositiveOrZero;

class RentableMutateForm extends InventoryMutateForm {
	private @NotNull @PositiveOrZero Double wholesalePrice;

	public Double getWholesalePrice() {
		return wholesalePrice;
	}

	public void setWholesalePrice(Double wholesalePrice) {
		this.wholesalePrice = wholesalePrice;
	}

	public static RentableMutateForm of(UniqueInventoryItem item) {
		Rentable product;
		if (item.getProduct() instanceof Rentable rentable) {
			product = rentable;
		} else {
			throw new IllegalArgumentException("Item must be for a product of type Rentable");
		}
		RentableMutateForm form = new RentableMutateForm();
		form.setName(product.getName());
		form.setQuantity(item.getQuantity().getAmount().longValueExact());
		form.setMetric(product.createQuantity(0).getMetric()); // hack
		form.setOrderTypes(orderTypesFromCategories(product.getCategories()));
		form.setWholesalePrice(product.getWholesalePrice().getNumber().doubleValueExact());
		form.setRetailPrice(product.getRetailPrice().getNumber().doubleValueExact());
		return form;
	}

	@Override
	public Product toProduct() {
		return new Rentable(
				getName(),
				Money.of(getRetailPrice(), EURO),
				Money.of(getWholesalePrice(), EURO),
				getOrderTypes(),
				getMetric());
	}

	@Override
	protected void modifyProductPrimitive(Product product) {
		if (product instanceof Rentable rentable) {
			rentable.setWholesalePrice(Money.of(getWholesalePrice(), EURO));
		} else {
			throw new IllegalArgumentException("RentableMutateForm can only modify instances of Rentable");
		}
	}
}
