// SPDX-License-Identifier: AGPL-3.0-or-later
// SPDX-FileCopyrightText: 2023-2024 swt23w23
package catering.orderCatalog;

import catering.order.OrderType;
import jakarta.persistence.*;
import org.javamoney.moneta.Money;
import org.salespointframework.catalog.Product;
import org.salespointframework.quantity.Quantity;

import javax.money.MonetaryAmount;
import java.util.Map;
import java.util.Objects;

@Entity
public class CustomCatalogEntry {
	@Id
	@GeneratedValue(strategy = GenerationType.IDENTITY)
	@Column(name = "id")
	private Long id;
	private OrderType eventType;

	@ElementCollection
	private Map<Product, Quantity> products;
	private MonetaryAmount totalCost;

	public CustomCatalogEntry(OrderType eventType, Map<Product, Quantity> products, MonetaryAmount totalCost) {
		this.eventType = eventType;
		this.products = products;
		this.totalCost = totalCost;
	}

	public CustomCatalogEntry() {

	}

	public long getId() {
		return id;
	}

	public OrderType getEventType() {
		return eventType;
	}

	public Map<Product, Quantity> getProducts() {
		return products;
	}

	public MonetaryAmount getTotalCost() {
		MonetaryAmount totalCost = products.entrySet().stream()
			.map(e -> e.getKey().getPrice().multiply(e.getValue().getAmount().doubleValue()))
			.reduce(Money.of(0, "EUR"), MonetaryAmount::add);

		setTotalCost(totalCost);
		return totalCost;
	}

	public void setEventType(OrderType eventType) {
		this.eventType = eventType;
	}

	public void addProduct(Product product, Quantity count) {
		if (products.containsKey(product)) {
			this.products.put(product, products.get(product).add(count));
		} else {
			this.products.put(product, count);
		}
	}

	public void setProducts(Map<Product, Quantity> products) {
		this.products = products;
	}

	public void setTotalCost(MonetaryAmount totalCost) {
		this.totalCost = totalCost;
	}

	@Override
	public int hashCode() {
		return Objects.hash(CustomCatalogEntry.class, getId());
	}

	@Override
	public boolean equals(Object obj) {
		if (obj instanceof CustomCatalogEntry other) {
			return getId() == other.getId();
		}
		return false;
	}
}
