// SPDX-License-Identifier: AGPL-3.0-or-later
// SPDX-FileCopyrightText: 2023 swt23w23
package catering.users;

import org.springframework.stereotype.Component;
import org.springframework.validation.Errors;
import org.springframework.validation.ValidationUtils;
import org.springframework.validation.Validator;

@Component
public class FormValidator<F extends UserForm> implements Validator {

	@Override
	public boolean supports(Class<?> c) {
		return UserForm.class.isAssignableFrom(c);
	}

	@Override
	@SuppressWarnings("unchecked")
	public void validate(Object o, Errors e) {
		F form = (F) o;
		ValidationUtils.rejectIfEmptyOrWhitespace(e, "username", "username must not be empty");
		ValidationUtils.rejectIfEmptyOrWhitespace(e, "address", "address must not be empty");
		ValidationUtils.rejectIfEmptyOrWhitespace(e, "fullName", "fullName must not be empty");
		if (form instanceof UserFormWithPassword formWithPassword){
			formWithPassword.validatePassword(e);
		}
	}
}
