// SPDX-License-Identifier: AGPL-3.0-or-later
// SPDX-FileCopyrightText: 2023-2024 swt23w23
package catering.users;

import jakarta.persistence.Entity;
import jakarta.persistence.GeneratedValue;
import jakarta.persistence.Id;
import jakarta.persistence.OneToOne;

import java.util.Objects;

import org.salespointframework.useraccount.Role;
import org.salespointframework.useraccount.UserAccount;

@Entity
public class User {

	private @Id @GeneratedValue Long id;
	private String address, fullName;

	@OneToOne
	private UserAccount userAccount;

	@SuppressWarnings("unused")
	private User() {}

	public User(UserAccount userAccount, String address, String fullName){
		this.address = address;
		this.fullName = fullName;
		this.userAccount = userAccount;
	};

	public String getAddress(){
		return address;
	}

	public boolean setAddress(String address){
		this.address = address;
		return true;
		// NOTE: the return type is boolean,
		// because in the future we may want to check if the input is a real address
	};

	public String getUsername() {
		return userAccount.getUsername();
	};

	public boolean setUsername(String name){
		userAccount.setUsername(name);
		return true;
	}

	public String getFullName() {
		return fullName;
	};

	public boolean setFullName(String name){
		fullName = name;
		return true;
	}

	public UserAccount getUserAccount(){
		return this.userAccount;
	}

	public Long getId() {
		return id;
	}

	public boolean isEnabled(){
		return userAccount.isEnabled();
	}

	public boolean hasRole(String role) {
		return userAccount.getRoles().stream().toList().contains(Role.of(role));
	}

	@Override
	public int hashCode() {
		return Objects.hash(User.class, getId());
	}

	@Override
	public boolean equals(Object obj) {
		if (obj instanceof User other) {
			return getId().equals(other.getId());
		}
		return false;
	}
}
