// SPDX-License-Identifier: AGPL-3.0-or-later
// SPDX-FileCopyrightText: 2023-2024 swt23w23
package catering.users;

import java.util.Optional;

import org.springframework.validation.Errors;

/**
 * An extension of {@link UserForm} with a password attribute.
 */
public abstract class UserFormWithPassword extends UserForm {
	private final String password;

	public UserFormWithPassword(String username, String address, String fullName, String password) {
		super(username, address, fullName);
		this.password = password;
	}

	public String getPassword() {
		return password;
	}

	/**
	 * Template Method for validating the password.
	 *
	 * @param e {@link Errors} from {@link FormValidator}
	 */
	public void validatePassword(Errors e) {
		validatePasswordGeneric(e);
		Optional.ofNullable(e.getFieldValue("password")).map(s -> (String) s).ifPresent(s -> {
			if (s.chars().anyMatch(Character::isISOControl)) {
				e.rejectValue("password", "password must only contain printable characters");
			}
		});
	}

	/**
	 * Primitive Operation for validating the password depending on the subclass.
	 *
	 * @param e {@link Errors} from {@link FormValidator}
	 */
	public abstract void validatePasswordGeneric(Errors e);

}
