// SPDX-License-Identifier: AGPL-3.0-or-later
// SPDX-FileCopyrightText: 2023-2024 swt23w23
package catering.orderCatalog;

import static org.assertj.core.api.Assertions.assertThat;

import java.util.HashMap;
import java.util.Map;

import org.javamoney.moneta.Money;
import org.junit.jupiter.api.BeforeEach;
import org.junit.jupiter.api.Test;
import org.salespointframework.catalog.Product;
import org.salespointframework.inventory.UniqueInventory;
import org.salespointframework.inventory.UniqueInventoryItem;
import org.salespointframework.quantity.Quantity;
import org.springframework.beans.factory.annotation.Autowired;
import org.springframework.boot.test.context.SpringBootTest;

import catering.order.OrderType;

@SpringBootTest
public class CatalogControllerUnitTests {

	@Autowired
	CustomCatalogEntryRepository catalogEntryRepository;

	@Autowired
	UniqueInventory<UniqueInventoryItem> inventory;

	@BeforeEach
	void setup() {
		Product product1 = inventory.findAll().stream().toList().get(0).getProduct();
		Map<Product, Quantity> products = new HashMap<Product, Quantity>();
		products.put(product1, Quantity.of(1));

		CustomCatalogEntry catalogEntry1 = new CustomCatalogEntry(
				OrderType.EVENT_CATERING,
				products,
				Money.of(0, "EUR"));

		catalogEntryRepository.save(catalogEntry1);
	}

	@Test
	void countOfEntries() {
		// Includes entry of data initializer
		assertThat(catalogEntryRepository.findAll().stream().count()).isEqualTo(2);
	}
}
