// SPDX-License-Identifier: AGPL-3.0-or-later
// SPDX-FileCopyrightText: 2023-2024 swt23w23
package catering.orderCatalog;

import static org.junit.jupiter.api.Assertions.assertTrue;

import java.util.HashMap;
import java.util.Map;

import org.javamoney.moneta.Money;
import org.junit.jupiter.api.BeforeEach;
import org.junit.jupiter.api.Test;
import org.salespointframework.catalog.Product;
import org.salespointframework.inventory.UniqueInventory;
import org.salespointframework.inventory.UniqueInventoryItem;
import org.salespointframework.quantity.Quantity;
import org.springframework.beans.factory.annotation.Autowired;
import org.springframework.boot.test.context.SpringBootTest;

import catering.order.OrderType;

@SpringBootTest
public class CatalogUnitTests {

	@Autowired
	CustomCatalogEntryRepository catalogEntryRepository;

	@Autowired
	UniqueInventory<UniqueInventoryItem> inventory;

	private CustomCatalogEntry catalogEntry;

	@BeforeEach
	void setUp() {
		Product product1 = inventory.findAll().stream().toList().get(0).getProduct();
		Map<Product, Quantity> products = new HashMap<Product, Quantity>();
		products.put(product1, Quantity.of(1));

		this.catalogEntry = new CustomCatalogEntry(
				OrderType.EVENT_CATERING,
				products,
				Money.of(0, "EUR"));
	}

	@Test
	void testAddProduct() {
		catalogEntry.addProduct(inventory.findAll().stream().toList().get(0).getProduct(), Quantity.of(1));
		assertTrue(catalogEntry.getProducts().containsValue(Quantity.of(2)));
	}

	@Test
	void testSetEventType() {
		catalogEntry.setEventType(OrderType.PARTY_SERVICE);
		assertTrue(catalogEntry.getEventType().equals(OrderType.PARTY_SERVICE));
	}

	// Getter is being tested because it calculates totalCost before
	@Test
	void testGetTotalCost() {
		assertTrue(inventory.findAll().stream().toList().get(0).getProduct().getPrice()
				.equals(catalogEntry.getTotalCost()));
	}
}
