// SPDX-License-Identifier: AGPL-3.0-or-later
// SPDX-FileCopyrightText: 2023 swt23w23
package catering.users;

import static org.assertj.core.api.Assertions.assertThat;

import org.junit.jupiter.api.BeforeEach;
import org.junit.jupiter.api.Test;
import org.salespointframework.useraccount.UserAccount.UserAccountIdentifier;
import org.salespointframework.useraccount.UserAccountManagement;
import org.springframework.beans.factory.annotation.Autowired;
import org.springframework.boot.test.context.SpringBootTest;

@SpringBootTest
class UserDataInitializerIntegrationTests {
	@Autowired
	UserManagement userManagement;
	@Autowired
	UserAccountManagement userAccountManagement;

	UserDataInitializer userDataInitializer;

	@BeforeEach
	void init() {
		userDataInitializer = new UserDataInitializer(userManagement, userAccountManagement);
	}

	/**
	 * Test if the administrator’s account is only created once.
	 *
	 * If the admin is either replaced or attempted to be created a second time,
	 * the test will fail or throw an {@link IllegalArgumentException} respectively.
	 *
	 * @throws Exception
	 */
	@Test
	void onlyCreateAdminOnce() throws Exception {
		UserAccountIdentifier idBefore = userAccountManagement.findByUsername("admin").get().getId();
		userDataInitializer.initialize();
		UserAccountIdentifier idAfter = userAccountManagement.findByUsername("admin").get().getId();

		assertThat(idAfter).isEqualTo(idBefore);
	}
}
