// SPDX-License-Identifier: AGPL-3.0-or-later
// SPDX-FileCopyrightText: 2023-2024 swt23w23
package catering.users;

import static org.assertj.core.api.Assertions.assertThat;

import org.junit.jupiter.api.BeforeEach;
import org.junit.jupiter.api.Test;
import org.springframework.beans.factory.annotation.Autowired;
import org.springframework.boot.test.context.SpringBootTest;

@SpringBootTest
public class UserUnitTests {

	private User user;

	@Autowired
	private UserManagement userManagement;

	@BeforeEach
	void setUp() {
		user = userManagement.getUserByName("testUser")
				.orElseGet(() -> userManagement.createCustomer("testUser", "Baum Weg", "123", "Mario Götze"));
	}

	@Test
	void getAddress() {
		assertThat(user.getAddress()).isEqualTo("Baum Weg");
	}

	@Test
	void setAddress() {
		user.setAddress("Braum Weg");
		assertThat(user.getAddress()).isEqualTo("Braum Weg");
	}

	@Test
	void getUsername() {
		User otherUser = userManagement.createCustomer("testUser0", "password", "Apfel Weg", "Marco Reus");
		assertThat(otherUser.getUsername()).isEqualTo("testUser0");
	}

	@Test
	void setUsername() {
		user.setUsername("testUser1");
		assertThat(user.getUsername()).isEqualTo("testUser1");
	}

	@Test
	void getFullName() {
		assertThat(user.getFullName()).isEqualTo("Mario Götze");
	}

	@Test
	void setFullName() {
		user.setFullName("Manuel Neuer");
		assertThat(user.getFullName()).isEqualTo("Manuel Neuer");
	}

	@Test
	void isEnabled() {
		assertThat(user.isEnabled()).isTrue();
	}

	@Test
	void hasRole() {
		assertThat(user.hasRole("CUSTOMER")).isTrue();
		assertThat(user.hasRole("ADMIN")).isFalse();
	}

	@Test
	void differentUserDifferentHashCode() {
		User otherUser = userManagement.createCustomer("carlos", "123", "Baum Weg", "Marco Reus");
		assertThat(user.hashCode()).isNotEqualTo(otherUser.hashCode());
	}

	@Test
	void usersNotEqual() {
		User otherUser = userManagement.createCustomer("maria", "123", "Baum Weg", "Marco Reus");
		assertThat(user).isNotEqualTo(otherUser);
	}

	@Test
	void usersNotEqualToDifferentClass() {
		assertThat(user).isNotEqualTo(new Object());
	}

	@Test
	void differentAddressesNotEqual() {
		assertThat(user.getAddress()).isNotEqualTo("Baum Straße");
	}

	@Test
	void differentUserNamesNotEqual() {
		assertThat(user.getUsername()).isNotEqualTo("TestUser");
	}
}
